<?php

/**
 * @package     Joomla.Plugin
 * @subpackage  System.accessibility
 *
 * @copyright   (C) 2023 Open Source Matters, Inc. <https://www.joomla.org>
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

\defined('_JEXEC') or die;

use Joomla\CMS\Extension\PluginInterface;
use Joomla\CMS\Factory;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\DI\Container;
use Joomla\DI\ServiceProviderInterface;
use Joomla\Event\DispatcherInterface;
use Joomla\Http\HttpFactory;
use Joomla\Plugin\Content\IndexNow\Extension\IndexNow;
use Joomla\Plugin\Content\IndexNow\Storage\SessionStorage;

return new class () implements ServiceProviderInterface {
    /**
     * Registers the service provider with a DI container.
     *
     * @param Container $container The DI container.
     *
     * @return  void
     *
     * @since   4.4.0
     */
    public function register(Container $container): void
    {
        $container->set(
            PluginInterface::class,
            function (Container $container) {
                $application = Factory::getApplication();

                if ($application === null) {
                    return null;
                }

                $httpFactory = new HttpFactory();
                $storage = new SessionStorage($application?->getSession());

                $plugin = new IndexNow(
                    dispatcher: $container->get(DispatcherInterface::class),
                    httpClient: $httpFactory->getHttp(),
                    storage: $storage,
                    config: (array)PluginHelper::getPlugin('content', 'indexnow')
                );
                $plugin->setApplication($application);

                return $plugin;
            }
        );
    }
};
