<?php

declare(strict_types=1);

namespace Joomla\Plugin\Content\IndexNow;

use Http\Discovery\Psr17FactoryDiscovery;
use Joomla\Plugin\Content\IndexNow\Exception\ClientResponseException;
use Joomla\Plugin\Content\IndexNow\Provider\ProviderInterface;
use Psr\Http\Client\ClientExceptionInterface;
use Psr\Http\Client\ClientInterface;
use Psr\Http\Message\RequestFactoryInterface;

final class Client
{
    private readonly RequestFactoryInterface $requestFactory;

    public function __construct(
        private readonly ProviderInterface $provider,
        private readonly ClientInterface $httpClient,
    ) {
        $this->requestFactory = Psr17FactoryDiscovery::findRequestFactory();
    }

    /**
     * Отправка ссылки на индексацию
     *
     * @throws ClientExceptionInterface
     * @throws \JsonException
     * @throws ClientResponseException
     */
    public function sendToIndex(string $pageUrl): void
    {
        $this->provider->setUrl($pageUrl);

        $request = $this->requestFactory->createRequest(
            method: 'GET',
            uri: $this->provider->getEndpoint(),
        );

        $response = $this->httpClient->sendRequest($request);

        if ($response->getStatusCode() !== 200) {
            $json = json_decode(
                (string) $response->getBody(),
                true,
                512,
                JSON_THROW_ON_ERROR
            );

            $e = new ClientResponseException($response->getReasonPhrase(), $response->getStatusCode());
            $e->setDetails($json);

            throw $e;
        }
    }
}
