<?php

declare(strict_types=1);

namespace Joomla\Plugin\Content\IndexNow\Storage;

use Joomla\Session\SessionInterface;

final class SessionStorage implements StorageInterface
{
    public function __construct(
        private readonly SessionInterface $session,
    )
    {
    }

    public function get(string $key, mixed $default = null): mixed
    {
        return $this->session->get(self::prepareKey($key), $default);
    }

    public function set(string $key, mixed $value): void
    {
        $this->session->set(
            name: self::prepareKey($key),
            value: $value
        );
    }

    public function delete(string $key): void
    {
        $this->session->remove(self::prepareKey($key));
    }

    private static function prepareKey(string $key): string
    {
        return sprintf('%s.%s', self::NAMESPACE, $key);
    }
}
