<?php

declare(strict_types=1);

namespace Joomla\Plugin\Content\IndexNow\UrlFetcher\Fetcher;

use Joomla\CMS\Router\Route;
use Joomla\Component\Content\Administrator\Table\ArticleTable;
use Joomla\Component\Content\Site\Helper\RouteHelper;

final class ArticleFetcher implements Fetcher
{
    use MetadataTrait;

    public function __construct(
        private readonly ArticleTable $articleTable
    )
    {
    }

    public function url(): string
    {
        $route = RouteHelper::getArticleRoute(
            id: $this->articleTable->getId(),
            catid: $this->articleTable->catid,
            language: $this->articleTable->language,
        );

        return Route::link(
            client: 'site',
            url: $route,
            absolute: true,
        );
    }

    public function isValid(): bool
    {
        $isPublic = $this->isPublic($this->articleTable);
        $isIndexed = !$this->hasNoIndex($this->articleTable);

        return $this->isPublished() && $isPublic && $isIndexed;
    }

    private function isPublished(): bool
    {
        $isPublished = (int) $this->articleTable->state === 1;

        if (!$isPublished) {
            return false;
        }

        $date = (new \DateTimeImmutable())->format('Y-m-d H:i:s');

        if ($this->articleTable->publish_up > $date) {
            return false;
        }

        if ($date > $this->articleTable->publish_down &&
            (
                $this->articleTable->publish_down !== '0000-00-00 00:00:00' &&
                $this->articleTable->publish_down !== null
            )
        ) {
            return false;
        }

        return true;
    }
}
