<?php

declare(strict_types=1);

namespace Joomla\Plugin\Content\IndexNow\UrlFetcher\Fetcher;

use Joomla\CMS\Router\Route;
use Joomla\Component\Categories\Administrator\Table\CategoryTable;
use Joomla\Component\Content\Site\Helper\RouteHelper;

final class CategoryFetcher implements Fetcher
{
    use MetadataTrait;

    public function __construct(
        private readonly CategoryTable $categoryTable
    )
    {
    }

    public function url(): string
    {
        $route = RouteHelper::getCategoryRoute(
            catid: $this->categoryTable->getId(),
            language: $this->categoryTable->language,
        );

        return Route::link(
            client: 'site',
            url: $route,
            absolute: true,
        );
    }

    public function isValid(): bool
    {
        $published = (int)$this->categoryTable->published === 1;
        $isPublic = $this->isPublic($this->categoryTable);
        $isIndexed = !$this->hasNoIndex($this->categoryTable);

        return $published && $isPublic && $isIndexed;
    }
}
